{% extends "classic/layout.html" %}

{%- macro relbar() %}
{# modified from sphinx/themes/basic/layout.html #}
    <div class="related" role="navigation" aria-label="related navigation">
      <h3>{{ _('Navigation') }}</h3>
      <ul>
          {%- for rellink in rellinks %}
          <li class="right" {% if loop.first %}style="margin-right: 10px"{% endif %}>
              <a href="{{ pathto(rellink[0])|e }}" title="{{ rellink[1]|striptags|e }}"
                 {{ accesskey(rellink[2]) }}>{{ rellink[3] }}
              </a>
              {%- if not loop.first %}{{ reldelim2 }}{% endif %}
          </li>
          {%- endfor %}
          {%- block rootrellink %}
          <li><img src="{{ pathto('_static/' ~ theme_root_icon, 1) }}" alt="{{ theme_root_icon_alt_text }}" style="vertical-align: middle; margin-top: -1px"></li>
          <li><a href="{{theme_root_url}}">{{theme_root_name}}</a>{{ reldelim1 }}</li>
          <li class="switchers">
            <div class="language_switcher_placeholder"></div>
            <div class="version_switcher_placeholder"></div>
          </li>
          <li>
              {% if theme_root_include_title %}
              <a href="{{ pathto('index') }}">{{ shorttitle }}</a>{{ reldelim1 }}
              {% endif %}
          </li>
          {%- endblock %}
            {%- for parent in parents %}
                <li class="nav-item nav-item-{{ loop.index }}"><a href="{{ parent.link|e }}" {% if loop.last %}{{ accesskey("U") }}{% endif %}>{{ parent.title }}</a>{{ reldelim1 }}</li>
                {%- endfor %}
                <li class="nav-item nav-item-this"><a href="{{ link|e }}">{{ title }}</a></li>
            {% block relbaritems %}
            {%- if pagename != "search" and builder != "singlehtml" and builder != "htmlhelp" %}
                <li class="right">
                    {{ searchbox() }}
                    {{ reldelim2 }}
                </li>
            {%- endif %}
            <li class="right">{{ themeselector() }}{{ reldelim2 }}</li>
            {% endblock %}
      </ul>
    </div>
{%- endmacro %}

{%- macro searchbox() %}
{# modified from sphinx/themes/basic/searchbox.html #}
    {%- if builder != "htmlhelp" %}
    <div class="inline-search" role="search">
        <form class="inline-search" action="{{ pathto('search') }}" method="get">
          <input placeholder="{{ _('Quick search') }}" aria-label="{{ _('Quick search') }}" type="search" name="q" id="search-box">
          <input type="submit" value="{{ _('Go') }}">
        </form>
    </div>
    {%- endif %}
{%- endmacro %}

{%- macro themeselector() %}
<label class="theme-selector-label">
    {{ _('Theme') }}
    <select class="theme-selector" oninput="activateTheme(this.value)">
        <option value="auto" selected>{{ _('Auto') }}</option>
        <option value="light">{{ _('Light') }}</option>
        <option value="dark">{{ _('Dark') }}</option>
    </select>
</label>
{%- endmacro %}

{% block relbar1 %} {% if builder != 'qthelp' %} {{ relbar() }} {% endif %} {% endblock %}
{% block relbar2 %} {% if builder != 'qthelp' %} {{ relbar() }} {% endif %} {% endblock %}

{%- block extrahead -%}
    <link rel="stylesheet" href="{{ pathto('_static/pydoctheme_dark.css', 1) }}" media="(prefers-color-scheme: dark)" id="pydoctheme_dark_css">
    <link rel="shortcut icon" type="image/png" href="{{ pathto('_static/' ~ theme_root_icon, 1) }}">
    {%- if builder != "htmlhelp" %}
        {%- if not embedded %}
            <script type="text/javascript" src="{{ pathto('_static/copybutton.js', 1) }}"></script>
            <script type="text/javascript" src="{{ pathto('_static/menu.js', 1) }}"></script>
            <script type="text/javascript" src="{{ pathto('_static/search-focus.js', 1) }}"></script>
            <script type="text/javascript" src="{{ pathto('_static/themetoggle.js', 1) }}"></script>
        {%- endif -%}
    {%- endif -%}
    {{ super() }}
{%- endblock -%}

{%- block css -%}
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    {{ super() }}
{%- endblock -%}

{%- block body_tag %}
{{ super() }}
{%- if builder != 'htmlhelp' %}
<div class="mobile-nav">
    <input type="checkbox" id="menuToggler" class="toggler__input" aria-controls="navigation"
           aria-pressed="false" aria-expanded="false" role="button" aria-label="{{ _('Menu')}}">
    <nav class="nav-content" role="navigation">
        <label for="menuToggler" class="toggler__label">
            <span></span>
        </label>
        <span class="nav-items-wrapper">
            <a href="{{ theme_root_url }}" class="nav-logo">
                <img src="{{ pathto('_static/' ~ theme_root_icon, 1) }}" alt="{{ theme_root_icon_alt_text }}">
            </a>
            <span class="version_switcher_placeholder"></span>
            {%- if pagename != "search" and builder != "singlehtml" %}
            <form role="search" class="search" action="{{ pathto('search') }}" method="get">
                <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" class="search-icon">
                    <path fill-rule="nonzero" fill="currentColor" d="M15.5 14h-.79l-.28-.27a6.5 6.5 0 001.48-5.34c-.47-2.78-2.79-5-5.59-5.34a6.505 6.505 0 00-7.27 7.27c.34 2.8 2.56 5.12 5.34 5.59a6.5 6.5 0 005.34-1.48l.27.28v.79l4.25 4.25c.41.41 1.08.41 1.49 0 .41-.41.41-1.08 0-1.49L15.5 14zm-6 0C7.01 14 5 11.99 5 9.5S7.01 5 9.5 5 14 7.01 14 9.5 11.99 14 9.5 14z"></path>
                </svg>
                <input placeholder="{{ _('Quick search') }}" aria-label="{{ _('Quick search') }}" type="search" name="q">
                <input type="submit" value="{{ _('Go') }}">
            </form>
            {%- endif %}
        </span>
    </nav>
    <div class="menu-wrapper">
        <nav class="menu" role="navigation" aria-label="main navigation">
            <div class="language_switcher_placeholder"></div>
            {{ themeselector() }}
            {%- if logo %}
            <p class="logo">
                <a href="{{ pathto('index') }}">
                <img class="logo" src="{{ pathto('_static/' ~ logo, 1)|e }}" alt="Logo">
                </a>
            </p>
            {%- endif %}
            {%- for sidebartemplate in sidebars %}
            {%- include sidebartemplate %}
            {%- endfor %}
        </nav>
    </div>
</div>
{% endif -%}
{% endblock %}

{% block footer %}
    <div class="footer">
    &copy; {% if theme_copyright_url or hasdoc('copyright') -%}
      <a href="{% if theme_copyright_url %}{{ theme_copyright_url }}{% else %}{{ pathto('copyright') }}{% endif %}">
    {%- endif -%}
    {%- trans %}Copyright{% endtrans -%}
    {%- if theme_copyright_url or hasdoc('copyright') -%}
    </a>
    {%- endif %} {{ copyright|e }}.
    <br>
    {% trans %}This page is licensed under the Python Software Foundation License Version 2.{% endtrans %}
    <br>
    {% trans %}Examples, recipes, and other code in the documentation are additionally licensed under the Zero Clause BSD License.{% endtrans %}
    <br>
    {% if theme_license_url %}
      {% trans license_file=theme_license_url %}See <a href="{{ license_file }}">History and License</a> for more information.{% endtrans %}<br>
    {% endif %}
    {% if theme_hosted_on %}
      {% trans hosted_on=theme_hosted_on %}Hosted on {{ hosted_on }}.{% endtrans %}<br>
    {% endif %}
    <br>

    {% include "footerdonate.html" %}
    <br>

    {%- if last_updated %}
      {% trans last_updated=last_updated|e %}Last updated on {{ last_updated }}.{% endtrans %}
    {%- endif %}
    {% if theme_issues_url %}
      {% trans %}<a href="{{ theme_issues_url }}">Found a bug</a>?{% endtrans %}
    {% endif %}
    <br>

    {% trans sphinx_version=sphinx_version|e %}Created using <a href="https://www.sphinx-doc.org/">Sphinx</a> {{ sphinx_version }}.{% endtrans %}
    </div>
{% endblock %}
